@@ -1,10 +1,10 @@
 # Program to serve as a terminal copilot for the user
 import sys
 import argparse
-import os
 import subprocess
 import openai
 import os
+from simple_term_menu import TerminalMenu
 
 
 def main():
@@ -12,12 +12,12 @@ def main():
     parser.add_argument('command', type=str, nargs='+',
                         help='Describe the command you are looking for.')
     parser.add_argument('-v', '--verbose', action='store_true',
-                        help='increase output verbosity')  
+                        help='increase output verbosity')
     args = parser.parse_args()
 
     if args.verbose:
         print("Verbose mode enabled")
-    
+
     # run history -40 to get the last 40 commands
     # TODO to get more terminal context to work with..
     # TODO save history of previous user questions and answers
@@ -33,7 +33,11 @@ The user is currently in the following directory:
 That directory contains the following files:
 {subprocess.run(["ls"], capture_output=True).stdout.decode("utf-8")}
 The user has the following environment variables set:
-{os.environ.keys()}
+HOME={os.environ["HOME"]}
+USER={os.environ["USER"]}
+SHELL={os.environ["SHELL"]}
+COMMAND_MODE={os.environ["COMMAND_MODE"]}
+
 The user has the following aliases set:
 {subprocess.run(["alias"], capture_output=True).stdout.decode("utf-8")}
 
@@ -47,7 +51,7 @@ The command the user is looking for is:
 
     # Call openai api to get the command completion
     openai.api_key = os.environ.get("OPENAI_API_KEY")
-    if  openai.api_key is None:
+    if openai.api_key is None:
         print("Please set OPENAI_API_KEY environment variable")
         print("You can get an API key from https://beta.openai.com/account/api-keys")
         print("To set the environment variable, run:")
@@ -63,15 +67,13 @@ The command the user is looking for is:
         presence_penalty=0
     )
     # strip all whitespace from the response start or end
-    response = response.choices[0].text.strip()
-
-    print("The command you are looking for is:")
-    print(response)
-
-    user_respons = input("Is this the command you are looking for? Enter to copy to clipboard, n to try again:")
-    if user_respons == "" or user_respons == "y" or user_respons == "yes":
-        # copy the command to the clipboard
-        subprocess.run(["pbcopy"], input=response, encoding="utf-8")
-        print("The command has been copied to the clipboard")
-    else:
-        print("Try again with a more descriptive expleanation of the command you are looking for")
\ No newline at end of file
+    cmd = response.choices[0].text.strip()
+    print(f"\033[94m> {cmd}\033[0m")
+    options = ["execute", "copy"]
+    terminal_menu = TerminalMenu(options)
+    menu_entry_index = terminal_menu.show()
+    if menu_entry_index == 0:
+        os.system(cmd)
+    elif menu_entry_index == 1:
+        print("> copied")
+        subprocess.run(["pbcopy"], input=cmd, encoding="utf-8")
\ No newline at end of file
